@@ -19,5 +19,5 @@ def plugin_settings(settings):
         "NOTICES_SNOOZE_COUNT_LIMIT", settings.FEATURES["NOTICES_SNOOZE_COUNT_LIMIT"]
     )
     settings.FEATURES["NOTICES_SEGMENT_KEY"] = settings.AUTH_TOKENS.get(
-        "NOTICES_SEGMENT_KEY", settings.FEATURES["NOTICES_SEGMENT_KEY"]
+        "SEGMENT_KEY", settings.FEATURES["NOTICES_SEGMENT_KEY"]
     )
